@@ -39,22 +39,6 @@
 (add-hook 'riece-user-list-mode-hook 'riece-xemacs-hide-modeline)
 (add-hook 'riece-channel-list-mode-hook 'riece-xemacs-hide-modeline)
 
-(defun riece-xemacs-mode-line-buffer-identification (line)
-  "Decorate 1st	element	of `mode-line-buffer-identification' LINE.
-Modify whole identification by side effect."
-  (let ((id (car line)) chop)
-    (if (and (stringp id) (string-match "^Riece:" id))
-	(progn
-	  (setq chop (match-end 0))
-	  (nconc
-	   (list
-	    (cons (copy-extent modeline-buffer-id-left-extent)
-		  (substring id 0 chop))
-	    (cons (copy-extent modeline-buffer-id-right-extent)
-		  (substring id chop)))
-	   (cdr line)))
-      line)))
-
 (defun riece-xemacs-simplify-modeline-format ()
   "Remove unnecessary information from `modeline-format'."
   (setq modeline-format
@@ -62,9 +46,6 @@ Modify whole identification by side effect."
 		  (delq 'modeline-multibyte-status
 			(copy-sequence mode-line-format)))))
 
-(defalias 'riece-mode-line-buffer-identification
-  'riece-xemacs-mode-line-buffer-identification)
-
 (defalias 'riece-simplify-mode-line-format
   'riece-xemacs-simplify-modeline-format)
 
@@ -96,6 +77,46 @@ Modify whole identification by side effect."
 (defalias 'riece-overlay-start 'extent-start-position)
 (defalias 'riece-overlay-buffer 'extent-buffer)
 
+(defun riece-overlays-in (start end)
+  (extent-list (current-buffer) start end))
+
+(defalias 'riece-delete-overlay 'delete-extent)
+
+(defun riece-kill-all-overlays ()
+  "Delete all extents in the current buffer."
+  (map-extents (lambda (extent ignore)
+                 (delete-extent extent)
+                 nil)))
+
+;;; stolen (and renamed) from nnheaderxm.el.
+(defun riece-xemacs-generate-timer-name (&optional prefix)
+  (let ((counter '(0)))
+    (format "%s-%d"
+	    (or prefix
+		"riece-xemacs-timer")
+	    (prog1 (car counter)
+	      (setcar counter (1+ (car counter)))))))
+
+(defun riece-run-at-time (time repeat function &rest args)
+  (let ((name (riece-xemacs-generate-timer-name "riece-run-at-time")))
+    (start-itimer
+     name
+     `(lambda ()
+	(,function ,@args))
+     time repeat)
+    name))
+
+(defun riece-run-with-idle-timer (time repeat function &rest args)
+  (let ((name (riece-xemacs-generate-timer-name "riece-run-with-idle-timer")))
+    (start-itimer
+     name
+     `(lambda ()
+	(,function ,@args))
+     time repeat t)
+    name))
+
+(defalias 'riece-cancel-timer 'delete-itimer)
+
 (provide 'riece-xemacs)
 
 ;;; riece-xemacs.el ends here
